==> jc-1.4.0.tar.gz: soot/options/JBOptions.h <==
// public class soot.options.JBOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5e22beeb27690ba8 soot_options_JBOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_JBOptions_H_
#define _JC_soot_options_JBOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_JBOptions$sub_refs	_jc_soot_options_JBOptions$sub_refs;
typedef struct _jc_soot_options_JBOptions$sub_nonrefs	_jc_soot_options_JBOptions$sub_nonrefs;
typedef struct _jc_soot_options_JBOptions$refs	_jc_soot_options_JBOptions$refs;
typedef struct _jc_soot_options_JBOptions$nonrefs	_jc_soot_options_JBOptions$nonrefs;
typedef struct _jc_soot_options_JBOptions$object	_jc_soot_options_JBOptions$object;

typedef const struct _jc_soot_options_JBOptions$vmethods	_jc_soot_options_JBOptions$vmethods;
typedef const struct _jc_soot_options_JBOptions$vtable	_jc_soot_options_JBOptions$vtable;
typedef const struct _jc_soot_options_JBOptions$vtype	_jc_soot_options_JBOptions$vtype;

// Constructors
extern void _jc_soot_options_JBOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_JBOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_JBOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_JBOptions$object *);
extern jboolean _jc_soot_options_JBOptions$method$use__5foriginal__5fnames$0e6b9299509c92ec(_jc_env *, struct _jc_soot_options_JBOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_JBOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_JBOptions$method_info$use__5foriginal__5fnames$0e6b9299509c92ec;

// Virtual methods structure
struct _jc_soot_options_JBOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_JBOptions$object *);
	jboolean	(*use__5foriginal__5fnames$0e6b9299509c92ec)(_jc_env *, struct _jc_soot_options_JBOptions$object *);
};

// Vtable
struct _jc_soot_options_JBOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_JBOptions$vmethods	soot_options_JBOptions;
};

// Vtype
struct _jc_soot_options_JBOptions$vtype {
	_jc_type			type;
	_jc_soot_options_JBOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_JBOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_JBOptions$refs {
    _jc_soot_options_JBOptions$sub_refs	soot_options_JBOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_JBOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_JBOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_JBOptions$sub_nonrefs	soot_options_JBOptions;
};

// Object instance structure
struct _jc_soot_options_JBOptions$object {
	_jc_soot_options_JBOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_JBOptions$vtype	*vtype;
	_jc_soot_options_JBOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_JBOptions$vtype _jc_soot_options_JBOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_JBOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_JBOptions$class_object;

#endif	/* _JC_soot_options_JBOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/JBOptions.h <==
// public class soot.options.JBOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5e22beeb27690ba8 soot_options_JBOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_JBOptions_H_
#define _JC_soot_options_JBOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_JBOptions$sub_refs	_jc_soot_options_JBOptions$sub_refs;
typedef struct _jc_soot_options_JBOptions$sub_nonrefs	_jc_soot_options_JBOptions$sub_nonrefs;
typedef struct _jc_soot_options_JBOptions$refs	_jc_soot_options_JBOptions$refs;
typedef struct _jc_soot_options_JBOptions$nonrefs	_jc_soot_options_JBOptions$nonrefs;
typedef struct _jc_soot_options_JBOptions$object	_jc_soot_options_JBOptions$object;

typedef const struct _jc_soot_options_JBOptions$vmethods	_jc_soot_options_JBOptions$vmethods;
typedef const struct _jc_soot_options_JBOptions$vtable	_jc_soot_options_JBOptions$vtable;
typedef const struct _jc_soot_options_JBOptions$vtype	_jc_soot_options_JBOptions$vtype;

// Constructors
extern void _jc_soot_options_JBOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_JBOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_JBOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_JBOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_JBOptions$method$use__5foriginal__5fnames$0e6b9299509c92ec(_jc_env *, struct _jc_soot_options_JBOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_JBOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_JBOptions$method_info$use__5foriginal__5fnames$0e6b9299509c92ec;

// Virtual methods structure
struct _jc_soot_options_JBOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_JBOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*use__5foriginal__5fnames$0e6b9299509c92ec)(_jc_env *, struct _jc_soot_options_JBOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_JBOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_JBOptions$vmethods	soot_options_JBOptions;
};

// Vtype
struct _jc_soot_options_JBOptions$vtype {
	_jc_type			type;
	_jc_soot_options_JBOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_JBOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_JBOptions$refs {
    _jc_soot_options_JBOptions$sub_refs	soot_options_JBOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_JBOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_JBOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_JBOptions$sub_nonrefs	soot_options_JBOptions;
};

// Object instance structure
struct _jc_soot_options_JBOptions$object {
	_jc_soot_options_JBOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_JBOptions$vtype	*vtype;
	_jc_soot_options_JBOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_JBOptions$vtype _jc_soot_options_JBOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_JBOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_JBOptions$class_object;

#endif	/* _JC_soot_options_JBOptions_H_ */
